@@ -9,14 +9,12 @@ OpenTracing::Implementation::NoOp::Scope - NoOp, so code won't break!
 Objects of this class implement the required methods of the
 L<OpenTracing::Interface::Scope>,
 to be compliant during testing and allow applications to continue working
-without having to catch exceptions all the time.
+without having to catch acceptions all the time.
 
-None of the methods will do anything useful.
+None of the methods will do anything usefull.
 
 =cut
 
-our $VERSION = 'v0.72.1';
-
 
 
 use OpenTracing::Implementation::NoOp::Span;
@@ -27,7 +25,7 @@ sub new { bless {} }
 
 
 
-sub close { shift }
+sub close { }
 
 sub get_span {
     OpenTracing::Implementation::NoOp::Span->new( )
